@@ -15,3 +15,5 @@ EXTENSION_ARCHIVE_PATH = _sample_data_path('dwca-star-test-archive.zip')
 MULTIEXTENSIONS_ARCHIVE_PATH = _sample_data_path('dwca-2extensions.zip')
 IDS_ARCHIVE_PATH = _sample_data_path('dwca-ids.zip')
 UTF8EOL_ARCHIVE_PATH = _sample_data_path('dwca-utf8-eol-test.zip')
+DIRECTORY_ARCHIVE_PATH = _sample_data_path('dwca-simple-folder')
+DEFAULT_META_VALUES = _sample_data_path('dwca-meta-default-values')
